#
# spec file for package vagrant-libvirt
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1500
%global rb_build_versions ruby30
%global rb_build_abi ruby:3.0.0
%global rb_ruby_suffix ruby3.0
%else
%global rb_build_versions %rb_default_ruby
%global rb_build_abi %rb_default_ruby_abi
%global rb_ruby_suffix %rb_default_ruby_suffix
%endif

Name:           vagrant-libvirt
Version:        0.5.3
Release:        bp153.2.1
%define mod_name vagrant-libvirt
%define mod_full_name %{mod_name}-%{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

Requires:       libvirt
%ifarch %ix86 x86_64
Requires:       qemu-x86
%endif
# switch to %%elifarch once every platform that we care about has rpm >= 4.15
%ifarch %arm %arm64
Requires:       qemu-arm
%endif
Requires:       vagrant
# for virt-sysprep
Recommends:     guestfs-tools
BuildRequires:  vagrant

%if 0%{?suse_version} > 1500
BuildRequires:  %{ruby:3 < 3.1}
%else
BuildRequires:  %{ruby:2 >= 2.5}
%endif
BuildRequires:  ruby-macros >= 5

# for tests:
BuildRequires:  %{rubygem bundler}
BuildRequires:  %{rubygem rspec}
BuildRequires:  %{rubygem vagrant-spec}
# BuildRequire the same gems as Required
BuildRequires:  %{rubygem fog-core:2 >= 2.1}
BuildRequires:  %{rubygem fog-libvirt >= 0.3.}

# s.add_development_dependency "rspec-core", ">= 3.5"
BuildRequires:  %{rubygem rspec-core >= 3.5}
# s.add_development_dependency "rspec-expectations", ">= 3.5"
BuildRequires:  %{rubygem rspec-expectations >= 3.5}
# s.add_development_dependency "rspec-mocks", ">= 3.5"
BuildRequires:  %{rubygem rspec-mocks >= 3.5}
# s.add_development_dependency 'rake'
BuildRequires:  %{rubygem rake}

# s.add_runtime_dependency 'fog-libvirt', '>= 0.6.0'
Requires:       %{rubygem fog-libvirt >= 0.6.}
# s.add_runtime_dependency 'fog-core', '~> 2.1'
Requires:       %{rubygem fog-core:2 >= 2.1}
# s.add_runtime_dependency 'nokogiri', '~> 1.6'
Requires:       %{rubygem nokogiri:1 >= 1.6 }

# required when using a non-default ruby version
BuildRequires:  %{rubygem gem2rpm}

# Prevent: have choice for rubygem(ruby:2.7.0:childprocess) >= 0
BuildRequires:  %{rubygem childprocess > 3}

BuildRequires:  fdupes

URL:            https://github.com/vagrant-libvirt/vagrant-libvirt
Source:         https://rubygems.org/gems/%{mod_full_name}.gem
Patch0:         0001-Remove-simplecov-from-tests.patch

Summary:        Vagrant provider for libvirt
License:        MIT

%description
This is a Vagrant plugin that adds a Libvirt provider to Vagrant, allowing
Vagrant to control and provision machines via the Libvirt toolkit.

%package        -n %{name}-doc
Summary:        Documentation for vagrant-libvirt

%description    -n %{name}-doc
This package contains the documentation for the Libvirt provider to Vagrant.


%global vagrant_plugin_name %{name}

%prep
%gem_unpack
# remove dropped or unneeded dependencies
sed -i '/simplecov/d' %{mod_full_name}.gemspec

# this is essentially https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1330
# FIXME: drop this on the next upstream release
sed -i 's/\["~> 3.5.0"\]/\[">= 3.5"\]/' %{mod_full_name}.gemspec
%autopatch -p1

%build
%gem_build

%install
%vagrant_plugin_install
%fdupes %{buildroot}%{vagrant_plugin_instdir}

%check
# Use the actual gemspec for tests
cp %{mod_full_name}/%{mod_full_name}.gemspec \
   %{buildroot}%{vagrant_plugin_instdir}/%{vagrant_plugin_name}.gemspec
pushd %{buildroot}%{vagrant_plugin_instdir}

# Create dummy Gemfile and load dependencies via the gemspec
echo "gem 'vagrant'" > Gemfile
echo "gem 'rdoc'" >> Gemfile
echo "gem 'vagrant-spec'" >> Gemfile
echo "gemspec" >> Gemfile

# Relax developement rspec dependency
sed -i '/rspec/ s/~>/>=/' %{vagrant_plugin_name}.gemspec

export GEM_PATH=%{vagrant_plugin_dir}:`ruby.%{vagrant_rb_ruby_suffix} -e "print Gem.path.join(':')"`
bundle exec rspec spec

rm %{vagrant_plugin_name}.gemspec
popd

%files
%{vagrant_plugin_instdir}
%{vagrant_plugin_cache}
%{vagrant_plugin_spec}

%doc %{mod_full_name}/README.md
%license %{mod_full_name}/LICENSE

%exclude %{vagrant_plugin_instdir}/.*
%exclude %{vagrant_plugin_instdir}/Gemfile
%exclude %{vagrant_plugin_instdir}/Rakefile
%exclude %{vagrant_plugin_instdir}/README.md
%exclude %{vagrant_plugin_instdir}/LICENSE

%files -n %{name}-doc
%doc %{vagrant_plugin_docdir}

%changelog
* Wed Aug  4 2021 Dan Čermák <dcermak@suse.com>
- Unrestrict rspec-* versions
  Rebase patch:
  * 0001-Remove-simplecov-from-tests.patch
* Sat Jun 12 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.5.3
  * Use qemu-img json output and compute virtual size.
* Tue Jun  8 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.5.2
  Closed issues:
  * Error occurred:
    VagrantPlugins::ProviderLibvirt::Action::HandleBoxImage::Open3
- Update to version 0.5.1
  Closed issues:
  * Value for "owner" vagrant option ends up as value for
    "access" libvirt option.
  Merged pull requests:
  * Provide Vagrantfile path in description by default.
  * Vagrant up expects machine data_dir to exist afterwards.
  * Handle extraction of keyfile from uri.
  * Handle custom port for remote libvirt.
  * add support for boot 'network' from a vagrant public_network.
- Update to version 0.5.0
  Major changes
  * Switch to use the vagrant built-in WaitForCommunicator action
    for SSH access. This may impact any action or trigger that was
    relying on WaitTillUp before attempting SSH.
  * Experiemental support for multi disk VMs using a new box format
  Fixed bugs:
  * vagrant destroy -f does not delete all metadata.
  Closed issues:
  * Error occurred:
    uninitialized constant VagrantPlugins::GuestLinux::Guest.
  * vagrant halt -f doesn't work as expected.
  * Updating vagrant-libvirt from 0.3 to 0.4.1 fails because new
    version cannot be "activated".
  * undefined method `name' for nil:NilClass (NoMethodError): Image
    remove fails if vm contains cdrom.
  * vagrant-libvirt plugin won't install on ARM64.
  * [Question] Failed to connect socket to
    '/var/run/libvirt/libvirt-sock-ro': No such file or directory.
  * Unusual disk image size created.
  * Ruby Gem rexml not builted-in.
  * vagrant destroy crashes due to nil volume in the domain.volumes
    collection.
  * libvirt__network_name doesn't work.
  * vagrant-libvirt no connection to REMOTE Provider after reboot.
  * verify the unit tests pass with rspec: 25 examples,23 failures
  Merged pull requests:
  * Make disks attribute path required check for name collisions.
  * Ensure state is correct reflected in global-status.
  * Invert forward ssh port behaviour.
  * Ensure state is fully removed for destroy.
  * Adjust forwarded ports test to include other network.
  * Enable forward ssh-port to host.
  * Exclude LIBVIRT_DEFAULT_URI from impacting tests.
  * Since Ruby 3.0 rexml needs to be required.
  * Corrections to two test testing tool.
  * Bugfix Additional Disks Storage File Ownership.
  * Retrieve disk format and virtual size directly.
  * Handle nil volumes when cd-rom attached.
  * Attempt to fix coveralls reporting.
  * Allow to use many disks in vagrant box for libvirt provider.
  * Support force halt behaviour.
  * Revert auto_config change in #1249 #1253
  * Add virtiofs Support to vagrant-libvirt.
  * Auto configuration for tunnel interfaces.
  * Add ability to define multiple private networks.
  * Add ability to manage bridge STP and delay parameters.
  * Support testing against ruby 3.0.
  * Fix forward_ports with ruby 3.0.
  * Fix interaction with reload plugin.
  * Add option to set management network MTU.
  * Add support for spinlocks hyperv feature.
* Tue Apr  6 2021 Dan Čermák <dcermak@suse.com>
- New upstream release 0.4.1
  Removed patches
  * 0001-Add-a-simple-Proc-extension-to-support-bindings.patch
  * 0002-Remove-simplecov-from-tests.patch
    (rebased as 0001-Remove-simplecov-from-tests.patch)
  Added patch:
  * 0001-Remove-simplecov-from-tests.patch
  [#] Changelog
  [#]# [0.4.1](https://github.com/vagrant-libvirt/vagrant-libvirt/tree/0.4.1) (2021-04-03)
  [Full Changelog](https://github.com/vagrant-libvirt/vagrant-libvirt/compare/0.4.0...0.4.1)
  * *Closed issues:**
- Got IP address, even though it's empty [\#1239](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1239)
- Please consider removing the contextual\_proc gem
  [\#1238](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1238)
- \[Request\]: Easy way to add plugin to docker image
  [\#1212](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1212)
- Allow declaring no inputs [\#1092](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1092)
  * *Merged pull requests:**
- Raise expected Timeout to ensure retryable retries
  [\#1241](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1241)
  ([electrofelix](https://github.com/electrofelix))
- Add a simple Proc extension to support bindings
  [\#1240](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1240) ([dcermak](https://github.com/dcermak))
- Ensure provisioner cleanup run early in destroy
  [\#1235](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1235)
  ([electrofelix](https://github.com/electrofelix))
- Replace obsolete usage of Vagrant.require\_plugin
  [\#1234](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1234)
  ([electrofelix](https://github.com/electrofelix))
* Mon Mar 29 2021 Dan Čermák <dcermak@suse.com>
- New upstream release 0.4.0
  Added patches:
  * 0001-Add-a-simple-Proc-extension-to-support-bindings.patch
  * 0002-Remove-simplecov-from-tests.patch
  [#] Changelog
  [#]# [0.4.0](https://github.com/vagrant-libvirt/vagrant-libvirt/tree/0.4.0) (2021-03-21)
  [Full Changelog](https://github.com/vagrant-libvirt/vagrant-libvirt/compare/0.3.0...0.4.0)
  * *Closed issues:**
- Fix usage/warning of not set identity file
  [\#1228](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1228)
- Vagrant stucks on "Waiting for SSH to become available" when using remote libvirt with LIBVIRT\_DEFAULT\_URI
  [\#1217](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1217)
- Windows 10 install problem : could not write value VagrantFeature to key
  [\#1215](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1215)
- vagrant plugin install vagrant-libvirt produces error: conflicting dependencies net-ssh \(\>= 2.6.5\) and
  net-ssh \(= 6.2.0.rc1\) [\#1210](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1210)
- Error while creating domain: Error saving the server: Call to virDomainDefineXML failed: invalid argument:
  could not find capabilities for domaintype=kvm
  [\#1208](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1208)
- libk5crypto.so.3: undefined symbol: EVP\_KDF\_ctrl, version OPENSSL\_1\_1\_1b
  [\#1203](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1203)
- Vagrant not sharing project directory to /vagrant in case of certain boxes
  [\#1201](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1201)
- Vagrant up not working on Fedora 33 [\#1185](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1185)
- vagrant-libvirt is missing rsync in the image
  [\#1183](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1183)
- Version tagging not working when using the release zip
  [\#1181](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1181)
- Network Interface Order? [\#1180](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1180)
- Error when updating domain settings: undefined method `strip' for nil:NilClass
  [\#1176](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1176)
- Support OpenRC [\#1175](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1175)
- What is the default host IP? [\#1174](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1174)
- ability to choose default boot interface when multiple interfaces
  [\#1173](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1173)
- NIC duplicates created when using vagrant-libvirt
  [\#1165](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1165)
- Remote libvirt host. Waiting for domain to get an IP address
  [\#1160](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1160)
- Cannot reate  [\#1147](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1147)
- vagrant cannot create vm [\#1133](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1133)
- Installation inside Docker [\#1128](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1128)
- Centos 8 /lib64/libk5crypto.so.3: undefined symbol: EVP\_KDF\_ctrl, version OPENSSL\_1\_1\_1b
  [\#1127](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1127)
- New box created using create\_box.sh - gets stuck at "Waiting for SSH to become available..."
  [\#1116](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1116)
- Does not install on Fedora 32 [\#1105](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1105)
-  default: Waiting for domain to get an IP address
  [\#1084](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1084)
- Plugin does not install on Fedora 31 [\#1082](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1082)
- Add support for virt-sysprep options [\#1077](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1077)
- add support for disk I/O options [\#998](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/998)
- storage :file fail with QEMU session [\#986](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/986)
- Install vargant-libvirt plugin issue [\#982](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/982)
- Installation on OpenSUSE Leap 15.0 fails [\#968](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/968)
- Add support for tpm\_version [\#965](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/965)
  * *Merged pull requests:**
- Ensure multi machine IP retrieval works [\#1232](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1232)
  ([electrofelix](https://github.com/electrofelix))
- Extract finalizing from the uri to a separate method
  [\#1231](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1231)
  ([electrofelix](https://github.com/electrofelix))
- Improve id\_ssh\_key\_file finalizing [\#1230](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1230)
  ([electrofelix](https://github.com/electrofelix))
- Bugfix some stray machine args after tidy up
  [\#1227](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1227)
  ([electrofelix](https://github.com/electrofelix))
- Move proxy\_command to config and support templating
  [\#1226](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1226)
  ([electrofelix](https://github.com/electrofelix))
- auto enable ssh connection [\#1225](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1225)
  ([electrofelix](https://github.com/electrofelix))
- Only set ssh connection params if transport is ssh
  [\#1224](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1224)
  ([electrofelix](https://github.com/electrofelix))
- Make LIBVIRT\_DEFAULT\_URI a fackball mechanism
  [\#1223](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1223)
  ([electrofelix](https://github.com/electrofelix))
- Use OpenSSH functionality instead of netcat for proxy\_command
  [\#1222](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1222)
  ([electrofelix](https://github.com/electrofelix))
- Remove flag-name due to behaviour mismatch
  [\#1220](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1220)
  ([electrofelix](https://github.com/electrofelix))
- Refactor uri config tests [\#1219](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1219)
  ([electrofelix](https://github.com/electrofelix))
- Fix remote libvirt functionality through LIBVIRT\_DEFAULT\_URI
  [\#1218](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1218)
  ([ElArtista](https://github.com/ElArtista))
- Added notes on how to download source RPMS for CentOS 8 stream
  [\#1213](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1213) ([nmaludy](https://github.com/nmaludy))
- Ensure github actions run on merge to main branch
  [\#1207](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1207)
  ([electrofelix](https://github.com/electrofelix))
- Switch from travis to github actions for unit tests
  [\#1206](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1206)
  ([electrofelix](https://github.com/electrofelix))
- Consolidate ip address retreival to single method
  [\#1199](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1199)
  ([electrofelix](https://github.com/electrofelix))
- Use correct shell variable for options pass-thru
  [\#1197](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1197)
  ([electrofelix](https://github.com/electrofelix))
- Make a virtual machine disk sparse with `virt-sparsify`
  [\#1195](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1195) ([hswong3i](https://github.com/hswong3i))
- Improving Docker based Installation [\#1194](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1194)
  ([pgillich](https://github.com/pgillich))
- Update TOC with recent additions [\#1189](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1189)
  ([electrofelix](https://github.com/electrofelix))
- Include recent vagrant release in tests [\#1188](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1188)
  ([electrofelix](https://github.com/electrofelix))
- Support building from git-archive tarballs
  [\#1187](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1187)
  ([electrofelix](https://github.com/electrofelix))
- Include rsync to support syncing folders [\#1186](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1186)
  ([electrofelix](https://github.com/electrofelix))
- Fix Broken `/etc/machine-id` by `vagrant package` due to virt-sysprep's `customize` operation
  [\#1184](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1184) ([hswong3i](https://github.com/hswong3i))
- Exclude spec helpers from coverage [\#1179](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1179)
  ([electrofelix](https://github.com/electrofelix))
- Reduce start domain unnecessary domain redefines
  [\#1178](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1178)
  ([electrofelix](https://github.com/electrofelix))
- Provide uid/gid for additional volumes qemu:///session
  [\#1170](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1170)
  ([electrofelix](https://github.com/electrofelix))
- Add doc on ssh key replacement if repackaging
  [\#1169](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1169)
  ([electrofelix](https://github.com/electrofelix))
- Add ability to use emulated tpm [\#1166](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1166)
  ([JTarasovic](https://github.com/JTarasovic))
- Use Github actions for integration tests against Vagrant-libvirt
  [\#1091](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1091) ([abbbi](https://github.com/abbbi))
- Add support for configuring memballoon-related settings
  [\#1083](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1083) ([erhudy](https://github.com/erhudy))
- Add support for clock setup [\#1047](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1047)
  ([zzambers](https://github.com/zzambers))
- Add disk driver options with minor refactor
  [\#1000](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1000)
  ([davidscaife](https://github.com/davidscaife))
* Fri Nov 20 2020 Dan Čermák <dcermak@suse.com>
- New upstream release 0.3.0
  [#] Changelog
  [#]# [0.3.0](https://github.com/vagrant-libvirt/vagrant-libvirt/tree/0.3.0) (2020-11-16)
  [Full Changelog](https://github.com/vagrant-libvirt/vagrant-libvirt/compare/0.2.1...0.3.0)
  * *Closed issues:**
- Support parameters for openvswitch network configuration [\#1155](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1155)
- Correctly support the new --no-tty option [\#1106](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1106)
  * *Merged pull requests:**
- Update issue template to request log be attached [\#1168](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1168) ([electrofelix](https://github.com/electrofelix))
- Rudimentary start domain action spec [\#1167](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1167) ([electrofelix](https://github.com/electrofelix))
- Use github cache for docker layers [\#1164](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1164) ([electrofelix](https://github.com/electrofelix))
- Gemfile: update branch-name of 'vagrant-spec' [\#1163](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1163) ([kfix](https://github.com/kfix))
- Ensure docker image build has history for version resolving [\#1162](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1162) ([electrofelix](https://github.com/electrofelix))
- Tag version from git tag [\#1161](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1161) ([electrofelix](https://github.com/electrofelix))
- Try using bundler cache for faster CI [\#1159](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1159) ([electrofelix](https://github.com/electrofelix))
- Add rudimentary create domain spec test [\#1158](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1158) ([electrofelix](https://github.com/electrofelix))
- Fix release workflow [\#1157](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1157) ([electrofelix](https://github.com/electrofelix))
- \#1155 support setting ovs interface id [\#1156](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1156) ([abbbi](https://github.com/abbbi))
- fix typo [\#1154](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1154) ([rwrr](https://github.com/rwrr))
- Limit docker image push [\#1152](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1152) ([electrofelix](https://github.com/electrofelix))
- Support separate storage pools for additional disks [\#1130](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1130) ([abbbi](https://github.com/abbbi))
- Support the newly-introduced --no-tty Vagrant's option [\#1120](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1120) ([mrc0mmand](https://github.com/mrc0mmand))
- Add forward mode 'open' to README [\#1118](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1118) ([IPv4v6](https://github.com/IPv4v6))
- With additional notes for Fedora [\#1107](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1107) ([buckaroogeek](https://github.com/buckaroogeek))
  \* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
* Thu Oct 22 2020 Dan Čermák <dcermak@suse.com>
  New upstream release 0.2.1
  [#]# [0.2.1](https://github.com/vagrant-libvirt/vagrant-libvirt/tree/0.2.1) (2020-10-03)
  [Full Changelog](https://github.com/vagrant-libvirt/vagrant-libvirt/compare/0.2.0...0.2.1)
  * *Closed issues:**
- Erubis dependency #1142
  [#]# [0.2.0](https://github.com/vagrant-libvirt/vagrant-libvirt/tree/0.2.0) (2020-10-03)
  [Full Changelog](https://github.com/vagrant-libvirt/vagrant-libvirt/compare/0.1.2...0.2.0)
  * *Closed issues:**
- First time using - vagrant up fails with network related errors [\#1146](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1146)
- Waiting for domain to get an IP address [\#1145](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1145)
- CentOS 8   fail to install libvirt Failed to build gem native extension [\#1135](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1135)
- `\<module:Util\>': uninitialized constant VagrantPlugins::ProviderLibvirt::Util::ErbTemplate \(NameError\) [\#1131](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1131)
- vagrant asking for VBoxManage binary [\#1125](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1125)
- after upgrading vagrant to 2.2.9 \(from 2.2.7\) a vagrant up destroys the domain on error [\#1122](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1122)
- Failure to detect second machine instance using Vagrant CLI [\#1121](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1121)
- Help/Feature-Request: Host-only management network [\#1117](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1117)
- libvirt plugin install FAILs to find existing "package configuration for libvirt is not found" [\#1104](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1104)
- Fedora box download is not available  [\#1070](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1070)
  * *Merged pull requests:**
- Support release notes generation [\#1150](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1150) ([electrofelix](https://github.com/electrofelix))
- Add docker image for vagrant-libvirt [\#1149](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1149) ([electrofelix](https://github.com/electrofelix))
- Use Vagrant::Util::TemplateRenderer instead of Erubis. [\#1144](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1144) ([voxik](https://github.com/voxik))
- config: allow for setting URI from environment [\#1141](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1141) ([electrofelix](https://github.com/electrofelix))
- Limit CI jobs to a subset of combinations [\#1140](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1140) ([electrofelix](https://github.com/electrofelix))
- Add @uri config tests and minor refactor [\#1139](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1139) ([electrofelix](https://github.com/electrofelix))
- Update test syntax to remove stubs [\#1138](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1138) ([electrofelix](https://github.com/electrofelix))
- let the user set the domain title and description [\#1137](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1137) ([rgl](https://github.com/rgl))
- remove redundant setting of default volume/backingStore mode [\#1134](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1134) ([eighthave](https://github.com/eighthave))
- Add WWN support [\#1123](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1123) ([cvoltz](https://github.com/cvoltz))
- update examples to use fedora/32-cloud-base [\#1119](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1119) ([timhughes](https://github.com/timhughes))
- add snapshot\_pool\_name to README [\#1114](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1114) ([abbbi](https://github.com/abbbi))
- action/forward\_ports.rb: Fix SSH tunnel spawning and PID tracking [\#1037](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1037) ([zakame](https://github.com/zakame))
- Add public\_address provider capability [\#1036](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1036) ([zakame](https://github.com/zakame))
* Thu Sep 10 2020 Dan Čermák <dcermak@suse.com>
- Require qemu-x86/arm on the x86/arm respectively
- Add constraint on the childprocess version to fix "have choice" errors
* Tue Sep  8 2020 Dan Čermák <dcermak@suse.com>
- Switch back to the default Ruby for Tumbleweed
  * Recommend guestfs-tools for virt-sysprep (needed for vagrant package with
    vagrant-libvirt)
* Thu Sep  3 2020 Dan Čermák <dcermak@suse.com>
- Change dependency on qemu-kvm from Recommends to Requires
* Wed Aug 19 2020 Dan Čermák <dcermak@suse.com>
- New upstream release 0.1.2
  Drop patches (integrated upstream):
  * 0001-Revert-back-to-development-versiongemspec-file..patch
  * 0002-Use-the-same-version-of-Nokogiri-as-Vagrant.patch
  * 0003-Update-fog-core-to-latest-version.patch
  v0.1.2:
  * #1110 prune_nfs_exports.rb:18:in call': undefined method info' for nil:NilClass
  v0.1.1
  * Merge pull request #1111 from AmedeeBulle/issue-1110
  v0.1.0
  * Improve Fedora installation procedure (#1101)
* Tue May 12 2020 Dan Čermák <dcermak@suse.com>
- Switch to Ruby 2.6 for Tumbleweed
* Mon Mar 23 2020 Dan Čermák <dcermak@suse.com>
- Add missing requires on nokogiri
* Wed Nov 13 2019 Dan Čermák <dcermak@suse.com>
- depend on nokogiri 1.10.x instead of hardcoding 1.10.4
* Fri Aug 23 2019 Dan Čermák <dcermak@suse.com>
- Bump nokogiri BuildRequires version
* Sun Jul  7 2019 Jan Engelhardt <jengelh@inai.de>
- Grammar fixes to the description.
* Tue Jul  2 2019 Dan Čermák <dcermak@suse.com>
- Remove obsolete gem2rpm.yml
* Tue Apr  2 2019 Dan Čermák <dcermak@suse.com>
- Restructure package into a system-wide vagrant plugin
* Mon Jan  7 2019 Dan Čermák <dcermak@suse.com>
- small fixes:
  * enhance %%description
  * remove github dotfiles from package
  * install vargrant-libvirt.json
  * remove /usr/bin/env bash from create_box.sh
* Thu Nov 22 2018 Stephan Kulow <coolo@suse.com>
- updated to version 0.0.45
  no changelog found
* Tue Feb 27 2018 factory-auto@kulow.org
- updated to version 0.0.43
  CHANGELOG.md removed upstream
* Thu Aug  3 2017 coolo@suse.com
- updated to version 0.0.40
  see installed CHANGELOG.md
* Tue May 16 2017 opensuse_buildservice@ojkastl.de
- added vagrant-libvirt.json
